# Captur ML SDK

This is an internal SDK to build Captur Machine Learning products.

<p><a href="https://captur.github.io/captur-ml-engine" target="_blank"><img src="https://img.shields.io/static/v1?style=for-the-badge&label=sdk&message=Documentation&color=informational"></a></p>

## Using this library

`pip install captur-ml`

## Publishing a new version of this library

`sh publish.sh`

## Building the docs
`pdoc --html captur_ml --template-dir docs/templates --output-dir docs --force`